#!/bin/bash

if [[ "$OSTYPE" == "darwin"* ]]; then
	export nbproc=`sysctl -n hw.physicalcpu`
else
	export nbproc=`nproc`	
fi

INSTALL_PREFIX="$1"

if [ -z "$1" ]
then
	if [ -z ${CONDA_ENV_PATH} ]
	then
		if [ -z ${CONDA_PREFIX} ]
		then
			INSTALL_PREFIX="$HOME/usr"
		else
			INSTALL_PREFIX=${CONDA_PREFIX}
		fi
	else
		INSTALL_PREFIX=${CONDA_ENV_PATH}
	fi
fi

export PATH=${INSTALL_PREFIX}/bin:${PATH}
export LD_LIBRARY_PATH=${INSTALL_PREFIX}/lib:${LD_LIBRARY_PATH}
export DYLD_LIBRARY_PATH=${INSTALL_PREFIX}/lib:${DYLD_LIBRARY_PATH}

if [ -d build ]
then
	echo "Remove existing directory build"
	rm -fr build
fi

mkdir -p build
cd build

cmake .. -DCMAKE_INSTALL_PREFIX=${INSTALL_PREFIX}
if [ $? != 0 ]
then
	echo "Error on cmake : exit -1"
	exit -1
fi

make -j $nbproc
if [ $? != 0 ]
then
	echo "Error on make : exit -1"
	exit -1
fi

make install -j $nbproc
if [ $? != 0 ]
then
	echo "Error on install : exit -1"
	exit -1
fi

